/* Open Source License

Copyright 2005 by Frank McCown
All rights reserved.

Developed by:  Frank McCown
               Old Dominion University
               http://www.cs.odu.edu/~fmccown

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal with the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

         - Redistributions of source code must retain the above copyright
           notice, this list of conditions and the following disclaimers.
         - Redistributions in binary form must reproduce the above copyright
           notice, this list of conditions and the following disclaimers in the
           documentation and/or other materials provided with the distribution.
         - Neither the names of Open Archives Initiative Metadata Harvesting
           Project, Old Dominion University, nor the names of
           its contributors may be used to endorse or promote products derived
           from this Software without specific prior written permission.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS WITH THE SOFTWARE.

*/

using System;
using System.Collections;
using System.ComponentModel;
using System.Web;
using System.Web.SessionState;

using System.Configuration;
using System.Xml;


namespace oaidemo 
{
	/// <summary>
	/// Summary description for Global.
	/// </summary>
	public class Global : System.Web.HttpApplication
	{
		public struct AcceptFormats
		{
			public string Format;
			public string Namespace;
			public string Schema;
			public string Handler;
		}

		public static string globalError = null;

		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.IContainer components = null;

		public Global()
		{
			InitializeComponent();
		}	
		
		protected void Application_Start(Object sender, EventArgs e)
		{
			GetConfigurationVariables();

			LoadDataSet();
		}
 
		protected void Session_Start(Object sender, EventArgs e)
		{

		}

		protected void Application_BeginRequest(Object sender, EventArgs e)
		{

		}

		protected void Application_EndRequest(Object sender, EventArgs e)
		{

		}

		protected void Application_AuthenticateRequest(Object sender, EventArgs e)
		{

		}

		protected void Application_Error(Object sender, EventArgs e)
		{

		}

		protected void Session_End(Object sender, EventArgs e)
		{

		}

		protected void Application_End(Object sender, EventArgs e)
		{

		}

		/**********************************************************************************/


		/// <summary>
		/// Load records from database, XML, etc.
		/// 
		/// Any changes made to database, XML, etc. would require restarting of web application in order
		/// for the changes to have an effect subsequent queries.
		/// </summary>
		private void LoadDataSet()
		{
			System.Data.DataSet ds = new System.Data.DataSet();
			
			string xmlSchemaFile = ConfigurationSettings.AppSettings["RecordsXmlSchemaFile"];
			try
			{
				ds.ReadXmlSchema(xmlSchemaFile);
			}
			catch (Exception e)
			{
				globalError = "Error loading " + xmlSchemaFile + ": " + e.Message;
			}

			string xmlDatafile = ConfigurationSettings.AppSettings["RecordsXmlFile"];
			try
			{
				ds.ReadXml(xmlDatafile);	
			}
			catch (Exception e)
			{
				globalError = "Error loading " + xmlDatafile + ": " + e.Message;
			}

			Application["RecordsDataSet"] = ds;
		}

		private void GetConfigurationVariables()
		{
			// Hard-code implementation protocol version
			Application["ProtocolVersion"] = "2.0";

			// Hard-code the date granularity supported by this repository
			Application["Granularity"] = "YYYY-MM-DD";

			Application["RepositoryName"] = ConfigurationSettings.AppSettings["RepositoryName"];
			Application["AdminEmail"] = ConfigurationSettings.AppSettings["AdminEmail"];
			Application["SupportSets"] = ConfigurationSettings.AppSettings["SupportSets"];
			Application["NamespaceIdentifier"] = ConfigurationSettings.AppSettings["OAIIdentifierNamespace"];
			Application["MaxListSets"] = ConfigurationSettings.AppSettings["MaxListSets"];
			Application["MaxListRecords"] = ConfigurationSettings.AppSettings["MaxListRecords"];
			Application["MaxListIdentifiers"] = ConfigurationSettings.AppSettings["MaxListIdentifiers"];
			Application["DateDelimiter"] = ConfigurationSettings.AppSettings["DateDelimiter"];

			// Read the XML configuration file (RepositoryDescription.xml) 

			string formats = ConfigurationSettings.AppSettings["MetadataFormats"];

			char[] seperator = {'\n'};
			string[] items = formats.Split(seperator);
			
			ArrayList acceptFormats = new ArrayList();
			AcceptFormats af = new AcceptFormats();

			try
			{
				for (int i = 0; i < items.Length; i += 4)
				{				
					af.Format = items[i].Trim();			
					af.Namespace = items[i+1].Trim();
					af.Schema = items[i+2].Trim();
					af.Handler = items[i+3].Trim();

					acceptFormats.Add(af);
				}
			}
			catch (System.IndexOutOfRangeException) 
			{
				globalError = "The Web.config file contains an illegal number of lines in the MetadataFormats. " +
					"Please make sure there are 4 lines for each metadata format.";
			}
			
			Application["AcceptFormats"] = acceptFormats;
		}
		
		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.components = new System.ComponentModel.Container();
		}
		#endregion
	}
}

