/* Open Source License

Copyright 2005 by Frank McCown
All rights reserved.

Developed by:  Frank McCown
               Old Dominion University
               http://www.cs.odu.edu/~fmccown

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
"Software"), to deal with the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

         - Redistributions of source code must retain the above copyright
           notice, this list of conditions and the following disclaimers.
         - Redistributions in binary form must reproduce the above copyright
           notice, this list of conditions and the following disclaimers in the
           documentation and/or other materials provided with the distribution.
         - Neither the names of Open Archives Initiative Metadata Harvesting
           Project, Old Dominion University, nor the names of
           its contributors may be used to endorse or promote products derived
           from this Software without specific prior written permission.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS WITH THE SOFTWARE.

*/

using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using System.IO;

namespace oaidemo
{
	/// <summary>
	/// Summary description for oai2.
	/// </summary>
	public class oai2 : System.Web.UI.Page
	{
		protected string responseDate;
		protected string errorMessage = null;
		protected string body;


		private void ProcessRequest()
		{
			if (Global.globalError != null)
			{
				errorMessage = Global.globalError;
			}
			else
			{
				// See if there is one verb

				string verb = Request.QueryString["verb"];
				if (verb == null)
				{
					errorMessage = "OAI verb is missing";
				}
				else if (verb.Trim().Length == 0)
				{
					errorMessage = "OAI verb is empty";
				}
				else 
				{
					verb = verb.Trim();

					StringWriter writer = new StringWriter();

					switch (verb)
					{
						case "GetRecord": 
							Server.Execute("GetRecord.aspx", writer);
							body = writer.ToString();
							break;
						case "Identify": 
							Server.Execute("Identify.aspx", writer);
							body = writer.ToString();
							break;
						case "ListMetadataFormats": 
							Server.Execute("ListMetadataFormats.aspx", writer);
							body = writer.ToString();
							break;
						case "ListIdentifiers": 
							Server.Execute("ListIdentifiers.aspx", writer);
							body = writer.ToString();
							break;
						case "ListRecords": 
							Server.Execute("ListRecords.aspx", writer);
							body = writer.ToString();
							break;
						case "ListSets": 
							Server.Execute("ListSets.aspx", writer);
							body = writer.ToString();
							break;
						case "Document": 
							break;
						default: errorMessage = "Illegal OAI verb=" + verb; 
							break;
					}
				}
			}

			if (errorMessage != null)
			{
				body = "<request>" + Application["BaseUrl"] + "</request>\n<error code=\"badVerb\">" + errorMessage + "</error>";	 			
			}
		}
			

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			
			Response.ContentType = "text/xml";
			Response.AddHeader("pragma", "no-cache");
			Response.AddHeader("cache-control", "private");

			responseDate = Util.NowUTC();

			string baseUrl = "http://" + Request.ServerVariables["SERVER_NAME"] + Request.Path;
			Application["baseUrl"] = baseUrl;


			ProcessRequest();

			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    

		}
		#endregion
	}
}
